#!/bin/bash

# startscript for datacrow

# activate for debugging
#set -x

#datacrow java directory
dcJavaDir=/usr/share/java/datacrow
# datacrow shared directory
dcSharedDir=/usr/share/datacrow
# datacrow home directory
dcHomeDir=$HOME/.datacrow

# creates a local working directory in user-home
function createLocalDir ()
{
	if [ ! -d $dcHomeDir ]; then
		echo "Creating local working directory $dcHomeDir ..."
		mkdir -p $dcHomeDir
	fi

	ln -sf $dcJavaDir/lib $dcHomeDir
	mkdir -p $dcHomeDir/plugins
	ln -sf $dcJavaDir/plugins/* $dcHomeDir/plugins

	for D in help icons resources services upgrade; do
		ln -sf $dcSharedDir/$D $dcHomeDir
	done

	# copy these since we need to store some changes
	[ -f $dcHomeDir/log4j.properties ] || cp $dcSharedDir/log4j.properties $dcHomeDir

	for D in modules reports; do
		[ -d $dcHomeDir/$D ] || cp -r $dcSharedDir/$D $dcHomeDir
	done

	mkdir -p $dcHomeDir/webapp/datacrow/mediaimages
	for D in common css images WEB-INF *.jsp; do
		ln -sf $dcSharedDir/webapp/datacrow/$D $dcHomeDir/webapp/datacrow
	done
}

function chkuser ()
{
	local you zen msg msg1 msg2 msg3 msg4 ugrp="users"
	local zenopt="--error --window-icon=/usr/share/pixmaps/datacrow.png"
	echo "Checking group \"$ugrp\""
	# your username
	you=$(id -nu)
	# check for zenity
	zen=$(which zenity 2>/dev/null)
	# check for group "users"
	msg1="Please run the following (as root)\nto add yourself to the $ugrp group\n\n"
	msg2="# groupadd $ugrp\n"
	msg3="# usermod -a -G $ugrp $you\n\n"
	msg4="then start Data Crow again"
	grep -qo "$ugrp" /etc/group
	if [ $? -ne 0 ]; then
		msg="${msg1}${msg2}${msg3}${msg4}"
		[ -n "$zen" ] && $zen $zenopt --title="Data Crow" --text="$msg" || echo -e "$msg"
		exit 1
	# check if user is a member of group "users"
	elif ! groups | grep -qo "$ugrp"; then
		msg="${msg1}${msg3}${msg4}"
		[ -n "$zen" ] && $zen $zenopt --title="Data Crow" --text="$msg" || echo -e "$msg"
		exit 1
	fi
}

echo ""
echo "Starting Data Crow ..."

# see if you are in group "users"
chkuser

# creates a local working directory in user-home
createLocalDir

# change to the working directory
echo "Changing to local working directory $dcHomeDir ..."
cd $dcHomeDir

# source the jpackage helpers
VERBOSE=1
. /usr/share/java-utils/java-functions

# set JAVA_* environment variables
set_javacmd
check_java_env
set_jvm_dirs

set_flags "-Xmx1024m"

CLASSPATH1=./help/
CLASSPATH2=`build-classpath hsqldb jaudiotagger log4j metadata-extractor JTattoo laf-plugin liquidlnf`
CLASSPATH3=`build-classpath avalon-framework batik-all fop commons-codec commons-io commons-logging`
CLASSPATH4=`build-classpath xalan-j2-serializer xalan-j2 xerces-j2 xmlgraphics-commons xsltc bcel regexp java-cup-runtime xml-commons-apis`
CLASSPATH5=`build-classpath jaxp itext jcommon jfreechart-swt jfreechart servlet swtgraphics2d`
CLASSPATH6=`build-classpath datacrow`
CLASSPATH=$CLASSPATH1:$CLASSPATH2:$CLASSPATH3:$CLASSPATH4:$CLASSPATH5:$CLASSPATH6
MAIN_CLASS="net.datacrow.core.DataCrow"

echo "Launching Data Crow ..."
run -dir:$dcHomeDir "$@"
echo "Exiting Data Crow ..."
